@@ -14,7 +14,7 @@
  *  limitations under the License.
  *
  * Img0ch.Template.Type
- * $Id: type.js 310 2007-03-03 14:06:01Z hikarin $
+ * $Id: type.js 749 2007-06-01 13:54:14Z hikarin $
  *
  */
 
@@ -43,20 +43,21 @@ Img0ch.Template.Type = (function(){
         var mail = res[1];
         if (mail) {
             divCaption.innerHTML = String(resno)
-                + "名前：<span class=\"commentator\"><a href=\"mailto:"
+                + "&nbsp;名前：<span class=\"commentator\"><a href=\"mailto:"
                 + mail + "\"><b>" + res[0] + "</b></a></span>："
                 + "<span class=\"commenttime\">" + res[2] + "</span>";
         }
         else {
             divCaption.innerHTML = String(resno)
-                + "名前：<span class=\"commentator\"><span class=\"nomail\">"
-                + "<b>" + res[0] + "</b></span></span>："
-                + "<span class=\"commenttime\">" + res[2] + "</span>";
+                + "&nbsp;名前：<span class=\"commentator\">"
+                + "<span class=\"nomail\"><b>" + res[0]
+                + "</b></span></span>：<span class=\"commenttime\">"
+                + res[2] + "</span>";
         }
         var pResBody  = document.createElement("p");
         pResBody.className = "res_body";
         pResBody.innerHTML =
-            parentObject.rewrite(String(res[3])) + "<br /><br />";
+            parentObject.rewrite( resno, String(res[3]) ) + "<br /><br />";
         divSection.appendChild(divCaption);
         divSection.appendChild(pResBody);
         root.appendChild(divSection);
