@@ -14,7 +14,7 @@
  *  limitations under the License.
  *
  * Zeromin
- * $Id: zeromin.js 227 2007-02-13 13:24:00Z hikarin $
+ * $Id: zeromin.js 242 2007-02-15 14:38:31Z hikarin $
  */
 
 function login() {
@@ -536,9 +536,11 @@ Zeromin.IO.prototype = {
             });
     },
     "upload": function(formId, callback) {
-        var success = function(rs) {
+        var success = function(res) {
             try {
-                eval("rs = " + jQuery(rs).text());
+                var rs;
+                eval("rs = " + res.replace(
+                    /^<[^>]+>/, "" ).replace( /<[^>]+>$/, "" ));
                 callback(new Zeromin.IO.Storage( rs, self, false ));
             } catch(e) {
                 console.log(e);
