@@ -14,15 +14,15 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Maple.pm 917 2007-07-20 15:34:41Z hikarin $
+# $Id: Maple.pm 946 2007-08-01 13:32:30Z hikarin $
 #
 
 package Img0ch::Maple;
 
 use strict;
 
-$Img0ch::Maple::RCS_ID   = '$Id: Maple.pm 917 2007-07-20 15:34:41Z hikarin $';
-$Img0ch::Maple::VERSION  = '2.1.15';
+$Img0ch::Maple::RCS_ID   = '$Id: Maple.pm 946 2007-08-01 13:32:30Z hikarin $';
+$Img0ch::Maple::VERSION  = '2.1.16';
 $Img0ch::Maple::revision = do {
     my @rv = $Img0ch::Maple::RCS_ID =~ /(\d+)/xms;
     $rv[0];
@@ -44,20 +44,56 @@ sub new {
 
 sub DESTROY { }
 
+my $unijp_charset_alias = {
+    'sjis'        => 'sjis',
+    'shiftjis'    => 'sjis',
+    'cp932'       => 'sjis',
+    'windows31j'  => 'sjis',
+    'macjapanese' => 'sjis',
+    'eucjp'       => 'euc-jp',
+    'ujis'        => 'euc-jp',
+    'eucjpwin'    => 'euc-jp',
+    'eucjpms'     => 'euc-jp',
+    'jis'         => 'jis',
+    '7bitjis'     => 'jis',
+    'iso2022jp'   => 'jis',
+    'utf8'        => 'utf8',
+    'ascii'       => 'ascii',
+    'iso88591'    => 'ascii',
+    'usascii'     => 'ascii',
+    'latin1'      => 'ascii',
+};
+
 sub get_encoding {
-    my ( $iMaple, $to_unijp ) = @_;
-    my $charset = $iMaple->{__config}->get('DefaultCharset') || 'Shift_JIS';
-    if ($to_unijp) {
-        return {
-            'Shift_JIS' => 'sjis',
-            'EUC-JP'    => 'euc-jp',
-            'UTF-8'     => 'utf8',
-            }->{$charset}
-            || 'sjis';
+    my ( $iKernel, $to_unijp ) = @_;
+    my $charset = $iKernel->{__config}->get('DefaultCharset') || 'Shift_JIS';
+
+    if ( $to_unijp ) {
+        $charset =~ tr/\-\_//;
+        $charset = $unijp_charset_alias->{lc $charset} || 'sjis';
     }
-    else {
-        return $charset;
+
+    return $charset;
+}
+
+sub get_encoded_str {
+    my ( $iKernel, $str, $to, $from ) = @_;
+    $str or return '';
+
+    require Unicode::Japanese;
+    $to ||= '';
+    $to =~ tr/\-\_//;
+    $to = $unijp_charset_alias->{$to} || $iKernel->get_encoding(1);
+    if ( !$from ) {
+        my $name = Unicode::Japanese->getcode($str);
+        $name eq $to and return $str;
+        $from = $name;
     }
+
+    my $unijp = $iKernel->{__unijp} ||= Unicode::Japanese->new();
+    $unijp->set( $str, $from );
+
+    return $unijp->conv($to);
 }
 
 sub get_config { $_[0]->{__config} }
@@ -143,6 +179,8 @@ sub rollback_transaction {
 
 sub create_repository_subdirs {
     my ( $time, $filename, $iObject ) = @_;
+
+    $time ||= 0;
     my ( undef, undef, undef, $day, $month, $year ) = localtime($time);
 
     $year  += 1900;
