@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Subject.pm 99 2007-01-16 13:52:38Z hikarin $
+# $Id: Subject.pm 904 2007-07-18 13:31:12Z hikarin $
 #
 
 package Img0ch::Subject;
@@ -26,9 +26,9 @@ sub new {
     my $iKernel = $iBBS->get_kernel();
 
     bless {
-        _bbs    => $iBBS->id(),
+        _bbs    => $iBBS->get_id(),
         _cache  => {},
-        __count => 0,
+        _count  => 0,
         _kernel => $iKernel,
         _order  => [],
         __path  => $iBBS->path('subject.txt'),
@@ -56,7 +56,7 @@ sub load {
 
     %{ $iSubject->{_cache} } = %{$buffer};
     my $count = @{ $iSubject->{_order} } = @{$order};
-    $iSubject->{__count} = $count;
+    $iSubject->{_count} = $count;
     return $count;
 }
 
@@ -65,7 +65,7 @@ sub save {
     my $iKernel = $iSubject->{_kernel};
 
     $path ||= $iSubject->{__path};
-    my $temp = $path . '.tmp';
+    my $temp    = $path . '.tmp';
     my $LOCK_EX = 2;
     eval {
         require Fcntl;
@@ -87,7 +87,9 @@ sub save {
         rename $temp, $path or $iKernel->throw_io_exception($path);
     };
     if ( my $exception = $@ ) {
-        unlink $temp or $iKernel->throw_io_exception($temp);
+        if ( -e $temp ) {
+            unlink $temp or $iKernel->throw_io_exception($temp);
+        }
         die $exception, "\n";
     }
     1;
@@ -103,7 +105,7 @@ sub get {
 
 sub flush {0}
 
-sub count { $_[0]->{__count} }
+sub count { $_[0]->{_count} }
 
 *stay = \&sage;
 
