@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Upload.pm 915 2007-07-19 15:02:38Z hikarin $
+# $Id: Upload.pm 920 2007-07-26 13:33:38Z hikarin $
 #
 
 package Img0ch::Upload;
@@ -287,8 +287,14 @@ sub _can {
     return 0;
 }
 
-sub get_digest {
-    my ( $iUpload, $path ) = @_;
+sub get_digest_raw { _get_digest( 'digest', @_ ) }
+
+sub get_digest_hex { _get_digest( 'hexdigest', @_ ) }
+
+sub get_digest { _get_digest( 'b64digest', @_ ) }
+
+sub _get_digest {
+    my ( $md5_method, $iUpload, $path ) = @_;
     my $iKernel = $iUpload->{_kernel};
 
     -r $path or return '';
@@ -301,7 +307,7 @@ sub get_digest {
     while ( read *FH, my $buffer, 32768 ) {
         $md5->add($buffer);
     }
-    my $digest = $md5->b64digest();
+    my $digest = $md5->$md5_method();
     close *FH or $iKernel->throw_io_exception($path);
     $digest;
 }
@@ -417,6 +423,21 @@ sub get_tag_count {
     return $ret;
 }
 
+sub get_tag_count_utf8 {
+    my ( $iUpload ) = @_;
+    my $iKernel     = $iUpload->{_kernel};
+    my $ret         = $iUpload->get_tag_count();
+    my $encoding    = $iKernel->get_encoding();
+    my $new_ret     = {};
+
+    while ( my ( $data, $count ) = each %$ret ) {
+        $data = $iKernel->get_encoded_str( $data, 'utf8', $encoding );
+        $new_ret->{$data} = $count;
+    }
+
+    return $new_ret;
+}
+
 sub set_tags {
     my ( $iUpload, $comment, $max, $resno, $no_commit ) = @_;
     $$comment =~ /<br>/xms or return 0;
