@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: BBS.pm 231 2007-02-13 15:06:05Z hikarin $
+# $Id: BBS.pm 900 2007-07-14 14:27:12Z hikarin $
 #
 
 package Zeromin::BBS;
@@ -57,10 +57,10 @@ sub create {
         $iRepos->set( "I:B.c.${id}", ( $hash->{category} || 1 ) );
         $iRepos->set( "I:B.d.${bbs}", $id );
         $iRepos->set( "I:B.i.${id}",  $bbs );
-        $iRepos->set( 'I:B._', $id );
-        $zBBS->{_id} = $id;
+        $iRepos->set( 'I:B._',        $id );
+        $zBBS->{_id}     = $id;
         $zBBS->{_system} = $iKernel->get_repos(
-            $iKernel->get_repos_path( "${bbs}/system" ) ),
+            $iKernel->get_repos_path("${bbs}/system") ),;
     }
 
     my $repos = join '/', $iConfig->get('RepositoryRoot'), $bbs;
@@ -96,6 +96,7 @@ sub create {
 
     require File::Copy;
     my $init = "${static}/init";
+
     #    if ( !-r "${path}/kanban.gif" ) {
     #        File::Copy::copy( "${init}/default_img.gif",
     #            "${path}/kanban.gif" )
@@ -110,17 +111,29 @@ sub create {
     my $zMeta = Zeromin::Metadata->new($zBBS);
     {
         local ( $!, *FH );
+
         my $head = join '/', $init, 'default_hed.txt';
-        open *FH, '<', $head or $iKernel->throw_io_exception($head);
-        $zMeta->head( \do { local $/ = undef; <FH> } );
+        open *FH, "<${head}"    ## no critic
+            or $iKernel->throw_io_exception($head);
+        $zMeta->head(
+            \do { local $/ = undef; <FH> }
+        );
         close *FH or $iKernel->throw_io_exception($head);
+
         my $meta = join '/', $init, 'default_fot.txt';
-        open *FH, '<', $meta or $iKernel->throw_io_exception($meta);
-        $zMeta->foot( \do { local $/ = undef; <FH> } );
+        open *FH, "<${meta}"    ## no critic
+            or $iKernel->throw_io_exception($meta);
+        $zMeta->foot(
+            \do { local $/ = undef; <FH> }
+        );
         close *FH or $iKernel->throw_io_exception($meta);
+
         my $t_end = join '/', $static, '1000.txt';
-        open *FH, '<', $t_end or $iKernel->throw_io_exception($t_end);
-        $zMeta->thread_end( \do { local $/ = undef; <FH> } );
+        open *FH, "<${t_end}"    ## no critic
+            or $iKernel->throw_io_exception($t_end);
+        $zMeta->thread_end(
+            \do { local $/ = undef; <FH> }
+        );
         close *FH or $iKernel->throw_io_exception($t_end);
     }
 
@@ -148,12 +161,10 @@ sub create {
     require Img0ch::Subject;
     my $iSubject = Img0ch::Subject->new($zBBS);
     $iSubject->save("${path}/subject.txt");
-
-    #            $args->{update} and $iSubject->update($zBBS);
-
     $iRepos->save();
-    $zBBS->update();
 
+    my $iRequest = $hash->{request};
+    $iRequest and $zBBS->update( undef, $iRequest );
     if ( !$rebuild ) {
         require Zeromin::Plugin;
         my $iBBS    = $zBBS->parent();
@@ -175,6 +186,7 @@ sub remove {
     require Zeromin::Metadata;
     require Zeromin::Plugin;
     require Zeromin::Setting;
+    require Zeromin::User;
     my $iBBS     = $zBBS->parent();
     my $iKernel  = $zBBS->get_kernel();
     my $iRepos   = $zBBS->get_common_repos();
@@ -201,7 +213,7 @@ sub remove {
     $zMeta->remove();
     $zSetting->remove();
     for my $object ( $zFIP, $zFNG ) {
-        map { $object->remove($_->{id}) } @{ $object->all_in() };
+        map { $object->remove( $_->{id} ) } @{ $object->all_in() };
         $object->save();
     }
 
@@ -230,8 +242,8 @@ sub remove {
 }
 
 sub rebuild {
-    my ($zBBS) = @_;
-    my $ret = $zBBS->create( { __rebuild => 1 } );
+    my ( $zBBS, $option ) = @_;
+    my $ret = $zBBS->create( { %{ $option || {} }, __rebuild => 1 } );
 
     require Zeromin::Plugin;
     my $iBBS    = $zBBS->parent();
@@ -242,12 +254,22 @@ sub rebuild {
 }
 
 sub update {
-    my ($zBBS) = @_;
-    -d $zBBS->path() or return 0;
+    my ( $zBBS, $id, $iRequest, $iKernel ) = @_;
+    my $iBBS;
+    if ( ( ref $zBBS || '' ) eq __PACKAGE__ ) {
+        -d $zBBS->path() or return 0;
+        $iBBS    = $zBBS->parent();
+        $iKernel = $zBBS->get_kernel();
+    }
+    else {
+        $iBBS = Img0ch::BBS->new( $iKernel, { id => $id } );
+        -d $iBBS->path() or return 0;
+    }
 
     require Img0ch::App::BBS;
-    my $iApp = Img0ch::App::BBS->new( $zBBS->get_kernel() );
-    my $iBBS = $zBBS->parent();
+    my $iApp = Img0ch::App::BBS->new( $iKernel, $iRequest->request() );
+    $iApp->request()->init( $iKernel->get_config() );
+    $iApp->trigger_plugin( 'bbs.init', 'DisableBBSInitPlugin', $iBBS );
     $iApp->update_subback($iBBS);
     $iApp->update_index($iBBS);
 
@@ -318,8 +340,10 @@ sub recreate_subject {
 sub repair_bbs_table {
     my ($zBBS)   = @_;
     my $iKernel  = $zBBS->get_kernel();
+    my $iConfig  = $iKernel->get_config();
     my $iRepos   = $zBBS->get_common_repos();
-    my $base     = $iKernel->get_config()->get('BBSPath');
+    my $base     = $iConfig->get('BBSPath');
+    my $rps_root = $iConfig->get('RepositoryRoot');
     my $last_id  = $iRepos->get('I:B._');
     my $repaired = [];
 
@@ -336,16 +360,16 @@ sub repair_bbs_table {
         $dir =~ /\A\.+\z/xms and next;
         $dir =~ /\A\W+\z/xms and next;
         $dir eq 'test' and next;
-        my $iBBSNew = Zeromin::BBS->new( $iKernel, { bbs => $dir } );
-        $iBBSNew->get_id() and next;
 
-        my $path = $iBBSNew->path();
+        my $path = join '/', $base, $dir;
+        -d $path or next;
         my $setting = join '/', $path, 'SETTING.TXT';
         -r $setting or next;
         my $setting_hash = {};
 
         local ( $!, *FH );
-        open *FH, '<', $setting or $iKernel->throw_io_exception($setting);
+        open *FH, "<${setting}"    ## no critic
+            or $iKernel->throw_io_exception($setting);
         while ( my $line = <FH> ) {
             chomp $line;
             $line =~ /\A(\w+)=(.+)\z/xms or next;
@@ -354,41 +378,53 @@ sub repair_bbs_table {
         }
         close *FH or $iKernel->throw_io_exception($setting);
 
-        my $id = +1;
-        $iRepos->set( "I:B.d.${dir}",     ++$last_id );
-        $iRepos->set( "I:B.i.${last_id}", $dir );
-        $iBBSNew->{_dir} = $dir;
-        $iBBSNew->{_id}  = $id;
-        $iRepos->save();
+        my $iBBSNew = Zeromin::BBS->new( $iKernel, { bbs => $dir } );
+        my $id = $iBBSNew->get_id();
+        if ( !$id ) {
+            $iRepos->set( "I:B.d.${dir}",     ++$last_id );
+            $iRepos->set( "I:B.i.${last_id}", $dir );
+            $id              = $last_id;
+            $iBBSNew->{_dir} = $dir;
+            $iBBSNew->{_id}  = $id;
+            $iRepos->save();
+        }
+
+        my $repos = join '/', $rps_root, $dir;
+        if ( !-d $repos ) {
+            mkdir $repos, 0755 or $iKernel->throw_io_exception($repos);
+        }
+
         my $zMeta = Zeromin::Metadata->new($iBBSNew);
         {
             local $/ = undef;
             local ( $!, *FH );
             my $head = join '/', $path, 'head.txt';
             if ( -r $head ) {
-                open *FH, '<', $head
+                open *FH, "<${head}"    ## no critic
                     or $iKernel->throw_io_exception($head);
                 $zMeta->head( \<FH> );
                 close *FH or $iKernel->throw_io_exception($head);
             }
             my $meta = join '/', $path, 'meta.txt';
             if ( -r $meta ) {
-                open *FH, '<', $meta
+                open *FH, "<${meta}"    ## no critic
                     or $iKernel->throw_io_exception($meta);
                 $zMeta->meta( \<FH> );
                 close *FH or $iKernel->throw_io_exception($meta);
             }
             my $foot = join '/', $path, 'foot.txt';
             if ( -r $foot ) {
-                open *FH, '<', $foot
+                open *FH, "<${foot}"    ## no critic
                     or $iKernel->throw_io_exception($foot);
                 $zMeta->foot( \<FH> );
                 close *FH or $iKernel->throw_io_exception($foot);
             }
         }
+
         my $zSetting = Zeromin::Setting->new($iBBSNew);
-        for my $key ( @{ $zSetting->keyset(1) } ) {
-            $zSetting->set( $key, $zSetting->get_default($key) );
+        for my $key ( @{ $zSetting->keyset() } ) {
+            $zSetting->set( $key,
+                $setting_hash->{$key} || $zSetting->get_default($key) );
         }
         $zSetting->save();
         push @$repaired, $dir;
@@ -397,6 +433,40 @@ sub repair_bbs_table {
     $repaired;
 }
 
+sub repair_tag_table {
+    my ($zBBS) = @_;
+
+    require Img0ch::Setting;
+    require Zeromin::Subject;
+    require Zeromin::Thread;
+    require Zeromin::Upload;
+    my $iBBS     = $zBBS->parent();
+    my $zSubject = Zeromin::Subject->new($zBBS);
+    my $zThread  = Zeromin::Thread->new( $zBBS, 0 );
+    my $zUpload  = Zeromin::Upload->new( $zBBS, 0 );
+    my $max      = Img0ch::Setting->new($iBBS)->get_int('BBS_IMG_TAG_MAX');
+
+    $zSubject->load();
+    $zThread->disable_xhtml_break();
+    $zUpload->remove_all_tag_data();
+BBS:
+    for my $key ( @{ $zSubject->to_array() } ) {
+        $zThread->set_key($key);
+        $zUpload->set_key($key);
+        $zUpload->count() or next BBS;
+        my $count = $zThread->count();
+    THREAD:
+        for ( my $i = 1; $i < $count; $i++ ) {
+            $zUpload->get($i)->[0] or next THREAD;
+            my $comment = $zThread->get($i)->[4];
+            $zUpload->set_tags( \$comment, $max, $i, 1 );
+        }
+    }
+    $zUpload->commit_tag_data();
+
+    return 1;
+}
+
 sub repair_upload_file_table {
     my ($zBBS) = @_;
     my $repaired = {};
@@ -412,8 +482,7 @@ sub repair_upload_file_table {
     my $zThread  = Zeromin::Thread->new( $zBBS, 0 );
     for my $key (@$result) {
         $zThread->set_key($key);
-        $plugin->($key);
-        $repaired->{$key} = $zThread->repair_upload_file_table();
+        $repaired->{$key} = $zThread->repair_upload_file_table($plugin);
     }
 
     $repaired;
@@ -467,7 +536,7 @@ sub category {
 }
 
 sub get {
-    my ( $zBBS, $id, $unijp ) = @_;
+    my ( $zBBS, $id, $unijp, $zCategory ) = @_;
     my $iRepos = $zBBS->get_common_repos();
     my $dir    = $iRepos->get("I:B.i.${id}");
 
@@ -477,6 +546,8 @@ sub get {
         my $iSetting = Img0ch::Setting->new($iBBS);
         my $name     = $iSetting->get('BBS_TITLE');
         my $subname  = $iSetting->get('BBS_SUBTITLE');
+        my $category = $iRepos->get("I:B.c.${id}") || 1;
+        my $cname    = $zCategory ? $zCategory->get_name($category) : '';
         if ($unijp) {
             $name    = $unijp->set( $name,    'sjis' )->get();
             $subname = $unijp->set( $subname, 'sjis' )->get();
@@ -485,7 +556,8 @@ sub get {
             name     => $name,
             subname  => $subname,
             dir      => $dir,
-            category => ( $iRepos->get("I:B.c.${id}") || 1 ),
+            category => $category,
+            cname    => $cname,
         };
     }
     else {
@@ -494,12 +566,29 @@ sub get {
             subname  => '',
             dir      => '',
             category => 0,
+            cname    => '',
         };
     }
 }
 
+sub gets {
+    my ( $zBBS, $bbs_ids, $unijp, $zCategory ) = @_;
+    my $result = [];
+    map { push @$result, $zBBS->get( $_, $unijp, $zCategory ) } @$bbs_ids;
+    return $result;
+}
+
+sub gets_with_page {
+    my ( $zBBS, $bbs_ids, $unijp, $zCategory, $item_per_page, $offset ) = @_;
+
+    require Data::Page;
+    my $entries = $zBBS->gets( $bbs_ids, $unijp, $zCategory );
+    my $page = Data::Page->new( scalar @$entries, $item_per_page, $offset );
+    return ( [ $page->splice($entries) ], $page );
+}
+
 sub all {
-    my ( $zBBS, $unijp ) = @_;
+    my ( $zBBS, $unijp, $zCategory ) = @_;
     my $id_table = {};
     my $ret      = [];
     my $iter     = $zBBS->get_common_repos()->iterate(
@@ -514,11 +603,20 @@ sub all {
     );
 
     for my $id ( keys %$id_table ) {
-        push @$ret, $zBBS->get( $id, $unijp );
+        push @$ret, $zBBS->get( $id, $unijp, $zCategory );
     }
     $ret;
 }
 
+sub all_with_page {
+    my ( $zBBS, $unijp, $zCategory, $item_per_page, $offset ) = @_;
+
+    require Data::Page;
+    my $entries = $zBBS->all( $unijp, $zCategory );
+    my $page = Data::Page->new( scalar @$entries, $item_per_page, $offset );
+    return ( [ $page->splice($entries) ], $page );
+}
+
 sub _update_subject {
     my ( $zBBS, $recreate, $at ) = @_;
 
@@ -528,13 +626,13 @@ sub _update_subject {
 
     $zSubject->load();
     my $count = $zSubject->update( $info, $recreate );
+    $info->{done} = $count;
 
     require Zeromin::Plugin;
     my $iBBS    = $zBBS->parent();
     my $zPlugin = Zeromin::Plugin->new($iBBS);
-    $zPlugin->do( $at, $iBBS );
+    $zPlugin->do( $at, $iBBS, [$info] );
 
-    $info->{done} = $count;
     $info;
 }
 
