@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Special.pm 802 2007-06-10 12:47:54Z hikarin $
+# $Id: Special.pm 925 2007-07-26 13:37:09Z hikarin $
 #
 
 package Zeromin::Thread::Special;
@@ -22,6 +22,17 @@ package Zeromin::Thread::Special;
 use strict;
 use base qw(Img0ch::Subject);
 
+sub get_utf8 {
+    my ( $zTS924, $key )  = @_;
+    my $iKernel           = $zTS924->{_kernel};
+    my ( $subject, $res ) = @{ $zTS924->get($key) };
+
+    $subject = $iKernel->get_encoded_str(
+        $subject, 'utf8', $iKernel->get_encoding(1) );
+
+    return [ $subject, $res ];
+}
+
 sub get_latest_key {
     my ($zTS924) = @_;
     my @keys = sort { $a cmp $b } @{ $zTS924->to_array() };
