@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: thread.pm 820 2007-06-15 15:15:25Z hikarin $
+# $Id: thread.pm 933 2007-07-29 12:24:06Z hikarin $
 #
 
 package Zeromin2::App::thread;
@@ -85,6 +85,40 @@ sub download_log {
     return load($zApp);
 }
 
+sub lookup {
+    my ($zApp) = @_;
+    $zApp->privilege( 'can_view_thread_log', 1 )
+        or return $zApp->return_value( 1, [] );
+
+    require Data::Page;
+    require Img0ch::Log;
+    require Zeromin2::Util;
+
+    my $ret      = [];
+    my $target   = $zApp->request()->param('target');
+    my $iKernel  = $zApp->kernel();
+    my $encoding = $iKernel->get_encoding(1);
+    my $iLog     = Img0ch::Log->new( $zApp->bbs(), 0 );
+    my $result   = $iLog->search($target);
+    my $page     = Data::Page->new( scalar @$result, $zApp->page_param() );
+
+    for my $log ( $page->splice($result) ) {
+        push @$ret, {
+            key     => $log->[0],
+            resno   => $log->[1],
+            date    => Zeromin2::Util::format_date( $log->[2] ),
+            ip      => $log->[3],
+            serial  => $log->[4],
+            agent   => $log->[5],
+            subject => $iKernel->get_encoded_str(
+                $log->[6], 'utf8', $encoding ),
+        }
+    }
+
+    $zApp->add_template_param( { Target => $target } );
+    return $zApp->return_value( 0, $ret, $page );
+}
+
 sub edit_res {
     my ($zApp) = @_;
     $zApp->check_csrf() or return $zApp->return_value(1);
